summaryrefslogtreecommitdiff
path: root/ctdb
diff options
context:
space:
mode:
authorAmitay Isaacs <amitay@gmail.com>2018-02-16 17:01:21 +1100
committerAmitay Isaacs <amitay@samba.org>2019-10-24 04:06:42 +0000
commit498932c0e8e8614bd52f3270c4d63e2b5f9e26a4 (patch)
treef122ed969d43f37e6c2defe65caef0ca8a2a4623 /ctdb
parent86521837b684df3b7c5a0a1e3b7e606c8b91f63e (diff)
downloadsamba-498932c0e8e8614bd52f3270c4d63e2b5f9e26a4.tar.gz
ctdb-vacuum: Replace VACUUM_FETCH message with control
Signed-off-by: Amitay Isaacs <amitay@gmail.com> Reviewed-by: Martin Schwenke <martin@meltin.net>
Diffstat (limited to 'ctdb')
-rw-r--r--ctdb/server/ctdb_vacuum.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/ctdb/server/ctdb_vacuum.c b/ctdb/server/ctdb_vacuum.c
index bdb00c3df0b..59fd1a54747 100644
--- a/ctdb/server/ctdb_vacuum.c
+++ b/ctdb/server/ctdb_vacuum.c
@@ -839,6 +839,7 @@ static void ctdb_process_vacuum_fetch_lists(struct ctdb_db_context *ctdb_db,
{
unsigned int i;
struct ctdb_context *ctdb = ctdb_db->ctdb;
+ int ret, res;
for (i = 0; i < ctdb->num_nodes; i++) {
TDB_DATA data;
@@ -857,17 +858,16 @@ static void ctdb_process_vacuum_fetch_lists(struct ctdb_db_context *ctdb_db,
ctdb_db->db_name));
data = ctdb_marshall_finish(vfl);
- if (ctdb_client_send_message(ctdb, ctdb->nodes[i]->pnn,
- CTDB_SRVID_VACUUM_FETCH,
- data) != 0)
- {
- DEBUG(DEBUG_ERR, (__location__ " Failed to send vacuum "
- "fetch message to %u\n",
+
+ ret = ctdb_control(ctdb, ctdb->nodes[i]->pnn, 0,
+ CTDB_CONTROL_VACUUM_FETCH, 0,
+ data, NULL, NULL, &res, NULL, NULL);
+ if (ret != 0 || res != 0) {
+ DEBUG(DEBUG_ERR, ("Failed to send vacuum "
+ "fetch control to node %u\n",
ctdb->nodes[i]->pnn));
}
}
-
- return;
}
/**
@@ -1197,7 +1197,7 @@ fail:
* - The vacuum_fetch lists
* (one for each other lmaster node):
* The records in this list are sent for deletion to
* their lmaster in a bulk VACUUM_FETCH message.
*
* The lmaster then migrates all these records to itelf
* so that they can be vacuumed there.
@@ -1197,7 +1197,7 @@ fail:
* (one for each other lmaster node):
* The records in this list are sent for deletion to
- * their lmaster in a bulk VACUUM_FETCH message.
+ * their lmaster in a bulk VACUUM_FETCH control.
*
* The lmaster then migrates all these records to itelf